@@ -79,19 +79,13 @@ Version: 0.2
 import sys
 import os
 
-try:
-    from ConfigParser import SafeConfigParser as ConfigParser
-except ImportError:
-    from configparser import ConfigParser
+from ansible.module_utils.six.moves.configparser import SafeConfigParser as ConfigParser
 
-try:
-    import json
-except ImportError:
-    import simplejson as json
+import json
 
 try:
     import libbrook
-except:
+except Exception:
     sys.exit('Brook.io inventory script requires libbrook. See https://github.com/doalitic/libbrook')
 
 
