@@ -6,7 +6,7 @@ The SoftLayer Python API client is required. Use `pip install softlayer` to inst
 You have a few different options for configuring your username and api_key. You can pass
 environment variables (SL_USERNAME and SL_API_KEY). You can also write INI file to
 ~/.softlayer or /etc/softlayer.conf. For more information see the SL API at:
-- https://softlayer-python.readthedocs.org/en/latest/config_file.html
+- https://softlayer-python.readthedocs.io/en/latest/config_file.html
 
 The SoftLayer Python client has a built in command for saving this configuration file
 via the command `sl config setup`.
@@ -36,10 +36,7 @@ import SoftLayer
 import re
 import argparse
 import itertools
-try:
-    import json
-except:
-    import simplejson as json
+import json
 
 
 class SoftLayerInventory(object):
@@ -52,7 +49,7 @@ class SoftLayerInventory(object):
         'primaryBackendIpAddress',
         'primaryIpAddress',
         'datacenter',
-        'tagReferences.tag.name',
+        'tagReferences',
         'userData.value',
     ]
 
@@ -85,7 +82,7 @@ class SoftLayerInventory(object):
             self.get_all_servers()
             print(self.json_format_dict(self.inventory, True))
         elif self.args.host:
-            self.get_virtual_servers()
+            self.get_all_servers()
             print(self.json_format_dict(self.inventory["_meta"]["hostvars"][self.args.host], True))
 
     def to_safe(self, word):
@@ -142,6 +139,12 @@ class SoftLayerInventory(object):
 
         dest = instance['primaryIpAddress']
 
+        instance['tags'] = list()
+        for tag in instance['tagReferences']:
+            instance['tags'].append(tag['tag']['name'])
+
+        del instance['tagReferences']
+
         self.inventory["_meta"]["hostvars"][dest] = instance
 
         # Inventory: group by memory
@@ -171,9 +174,8 @@ class SoftLayerInventory(object):
         # Inventory: group by type (hardware/virtual)
         self.push(self.inventory, instance_type, dest)
 
-        # Inventory: group by tag
-        for tag in instance['tagReferences']:
-            self.push(self.inventory, tag['tag']['name'], dest)
+        for tag in instance['tags']:
+            self.push(self.inventory, tag, dest)
 
     def get_virtual_servers(self):
         '''Get all the CCI instances'''
@@ -198,4 +200,5 @@ class SoftLayerInventory(object):
         self.get_virtual_servers()
         self.get_physical_servers()
 
+
 SoftLayerInventory()
